Users
All PUT endpoints update only the fields present in the body; see Updating Resources.
GET/v1/usersGET /v1/users
Code samples
cURL
# You can also use wget
curl -X GET /v1/users \
-H 'Accept: text/plain' \
-H 'x-api-key: API_KEY'
GET /v1/users
Gets the users based on the provided request.
Parameters
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| select | query | string | false | none |
| filter | query | string | false | none |
| include | query | string | false | none |
| sort | query | string | false | none |
| take | query | integer(int32) | false | none |
| skip | query | integer(int32) | false | none |
| roles | query | string | false | none |
Example responses
200 Response
{"success":true,"code":0,"message":"string","users":[{"id":"string","userName":"string","email":"string","phoneNumber":"string","title":"string","firstName":"string","lastName":"string","department":"string","birthDate":"2019-08-24T14:15:22Z","createdAt":"2019-08-24T14:15:22Z","updatedAt":"2019-08-24T14:15:22Z","lastDismissMessages":"2019-08-24T14:15:22Z","lastLogIn":"2019-08-24T14:15:22Z","rank":0,"image":"string","address":"string","postalCode":"string","region":"string","city":"string","country":"string","countryCode":"string","mobile":"string","notes":"string","customerId":0,"roles":["string"],"apiKeys":[{"id":0,"name":"string","key":"string","clientSecret":"string","createdDate":"2019-08-24T14:15:22Z","expireDate":"2019-08-24T14:15:22Z","ownerId":"string","revoked":true,"permissions":0,"description":"string"}],"settings":[{"id":0,"category":"string","group":"string","name":"string","value":"string","type":"string","description":"string","readOnly":true,"userId":"string"}]}],"totalUsersCount":0}{
"success": true,
"code": 0,
"message": "string",
"users": [
{
"id": "string",
"userName": "string",
"email": "string",
"phoneNumber": "string",
"title": "string",
"firstName": "string",
"lastName": "string",
"department": "string",
"birthDate": "2019-08-24T14:15:22Z",
"createdAt": "2019-08-24T14:15:22Z",
"updatedAt": "2019-08-24T14:15:22Z",
"lastDismissMessages": "2019-08-24T14:15:22Z",
"lastLogIn": "2019-08-24T14:15:22Z",
"rank": 0,
"image": "string",
"address": "string",
"postalCode": "string",
"region": "string",
"city": "string",
"country": "string",
"countryCode": "string",
"mobile": "string",
"notes": "string",
"customerId": 0,
"roles": [
"string"
],
"apiKeys": [
{
"id": 0,
"name": "string",
"key": "string",
"clientSecret": "string",
"createdDate": "2019-08-24T14:15:22Z",
"expireDate": "2019-08-24T14:15:22Z",
"ownerId": "string",
"revoked": true,
"permissions": 0,
"description": "string"
}
],
"settings": [
{
"id": 0,
"category": "string",
"group": "string",
"name": "string",
"value": "string",
"type": "string",
"description": "string",
"readOnly": true,
"userId": "string"
}
]
}
],
"totalUsersCount": 0
}Responses
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | OK | Management.GetUsersResponse |
Authentication: API key (x-api-key).
POST/v1/usersPOST /v1/users
Code samples
cURL
# You can also use wget
curl -X POST /v1/users \
-H 'Content-Type: application/json-patch+json' \
-H 'Accept: text/plain' \
-H 'x-api-key: API_KEY'
POST /v1/users
Inserts a new user.
Body parameter
{
"user": {
"id": "string",
"userName": "string",
"email": "string",
"phoneNumber": "string",
"title": "string",
"firstName": "string",
"lastName": "string",
"department": "string",
"birthDate": "2019-08-24T14:15:22Z",
"createdAt": "2019-08-24T14:15:22Z",
"updatedAt": "2019-08-24T14:15:22Z",
"lastDismissMessages": "2019-08-24T14:15:22Z",
"lastLogIn": "2019-08-24T14:15:22Z",
"rank": 0,
"image": "string",
"address": "string",
"postalCode": "string",
"region": "string",
"city": "string",
"country": "string",
"countryCode": "string",
"mobile": "string",
"notes": "string",
"customerId": 0,
"roles": [
"string"
],
"apiKeys": [
{
"id": 0,
"name": "string",
"key": "string",
"clientSecret": "string",
"createdDate": "2019-08-24T14:15:22Z",
"expireDate": "2019-08-24T14:15:22Z",
"ownerId": "string",
"revoked": true,
"permissions": 0,
"description": "string"
}
],
"settings": [
{
"id": 0,
"category": "string",
"group": "string",
"name": "string",
"value": "string",
"type": "string",
"description": "string",
"readOnly": true,
"userId": "string"
}
]
},
"password": "string"
}Parameters
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | Management.InsertUserRequest | false | The request containing the user to insert. |
Example responses
200 Response
{"userId":"string","success":true,"code":0,"message":"string"}{
"userId": "string",
"success": true,
"code": 0,
"message": "string"
}Responses
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | OK | Management.InsertUserResponse |
Authentication: API key (x-api-key).
PUT/v1/usersPUT /v1/users
Code samples
cURL
# You can also use wget
curl -X PUT /v1/users \
-H 'Content-Type: application/json-patch+json' \
-H 'Accept: text/plain' \
-H 'x-api-key: API_KEY'
PUT /v1/users
Updates a user.
Body parameter
{
"user": {
"id": "string",
"userName": "string",
"email": "string",
"phoneNumber": "string",
"title": "string",
"firstName": "string",
"lastName": "string",
"department": "string",
"birthDate": "2019-08-24T14:15:22Z",
"createdAt": "2019-08-24T14:15:22Z",
"updatedAt": "2019-08-24T14:15:22Z",
"lastDismissMessages": "2019-08-24T14:15:22Z",
"lastLogIn": "2019-08-24T14:15:22Z",
"rank": 0,
"image": "string",
"address": "string",
"postalCode": "string",
"region": "string",
"city": "string",
"country": "string",
"countryCode": "string",
"mobile": "string",
"notes": "string",
"customerId": 0,
"roles": [
"string"
],
"apiKeys": [
{
"id": 0,
"name": "string",
"key": "string",
"clientSecret": "string",
"createdDate": "2019-08-24T14:15:22Z",
"expireDate": "2019-08-24T14:15:22Z",
"ownerId": "string",
"revoked": true,
"permissions": 0,
"description": "string"
}
],
"settings": [
{
"id": 0,
"category": "string",
"group": "string",
"name": "string",
"value": "string",
"type": "string",
"description": "string",
"readOnly": true,
"userId": "string"
}
]
},
"currentPassword": "string",
"newPassword": "string"
}Parameters
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | Management.UpdateUserRequest | false | The request containing the user to update. |
Example responses
200 Response
{"success":true,"code":0,"message":"string"}{
"success": true,
"code": 0,
"message": "string"
}Responses
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | OK | Management.UpdateUserResponse |
Authentication: API key (x-api-key).
DELETE/v1/users/{userId}DELETE /v1/users/{userId}
Code samples
cURL
# You can also use wget
curl -X DELETE /v1/users/{userId} \
-H 'Accept: text/plain' \
-H 'x-api-key: API_KEY'
DELETE /v1/users/\{userId\}
Deletes a user.
Parameters
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| userId | path | string | true | The ID of the user to delete. |
Example responses
200 Response
{"success":true,"code":0,"message":"string"}{
"success": true,
"code": 0,
"message": "string"
}Responses
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | OK | Management.DeleteUserResponse |
Authentication: API key (x-api-key).
GET/v1/users/{userId}/settingsGET /v1/users/{userId}/settings
Code samples
cURL
# You can also use wget
curl -X GET /v1/users/{userId}/settings \
-H 'Accept: text/plain' \
-H 'x-api-key: API_KEY'
GET /v1/users/\{userId\}/settings
Retrieves the user settings based on the provided request.
Parameters
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| userId | path | string | true | The user ID. |
| select | query | string | false | none |
| filter | query | string | false | none |
| include | query | string | false | none |
| sort | query | string | false | none |
| take | query | integer(int32) | false | none |
| skip | query | integer(int32) | false | none |
Example responses
200 Response
{"success":true,"code":0,"message":"string","settings":[{"id":0,"category":"string","group":"string","name":"string","value":"string","type":"string","description":"string","readOnly":true,"userId":"string"}],"totalSettingsCount":0}{
"success": true,
"code": 0,
"message": "string",
"settings": [
{
"id": 0,
"category": "string",
"group": "string",
"name": "string",
"value": "string",
"type": "string",
"description": "string",
"readOnly": true,
"userId": "string"
}
],
"totalSettingsCount": 0
}Responses
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | OK | Management.GetUserSettingsResponse |
Authentication: API key (x-api-key).
POST/v1/users/{userId}/settingsPOST /v1/users/{userId}/settings
Code samples
cURL
# You can also use wget
curl -X POST /v1/users/{userId}/settings \
-H 'Content-Type: application/json-patch+json' \
-H 'Accept: text/plain' \
-H 'x-api-key: API_KEY'
POST /v1/users/\{userId\}/settings
Inserts new user settings based on the provided request.
Body parameter
{
"setting": {
"id": 0,
"category": "string",
"group": "string",
"name": "string",
"value": "string",
"type": "string",
"description": "string",
"readOnly": true,
"userId": "string"
}
}Parameters
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| userId | path | string | true | The user ID. |
| body | body | Management.InsertUserSettingRequest | false | The request containing the user settings to insert. |
Example responses
200 Response
{"settingId":0,"success":true,"code":0,"message":"string"}{
"settingId": 0,
"success": true,
"code": 0,
"message": "string"
}Responses
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | OK | Management.InsertUserSettingResponse |
Authentication: API key (x-api-key).
PUT/v1/users/{userId}/settingsPUT /v1/users/{userId}/settings
Code samples
cURL
# You can also use wget
curl -X PUT /v1/users/{userId}/settings \
-H 'Content-Type: application/json-patch+json' \
-H 'Accept: text/plain' \
-H 'x-api-key: API_KEY'
PUT /v1/users/\{userId\}/settings
Updates user settings based on the provided request.
Body parameter
{
"setting": {
"id": 0,
"category": "string",
"group": "string",
"name": "string",
"value": "string",
"type": "string",
"description": "string",
"readOnly": true,
"userId": "string"
}
}Parameters
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| userId | path | string | true | The user ID. |
| body | body | Management.UpdateUserSettingRequest | false | The request containing the user settings to update. |
Example responses
200 Response
{"settingsId":0,"success":true,"code":0,"message":"string"}{
"settingsId": 0,
"success": true,
"code": 0,
"message": "string"
}Responses
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | OK | Management.UpdateUserSettingResponse |
Authentication: API key (x-api-key).
DELETE/v1/users/{userId}/settings/{settingId}DELETE /v1/users/{userId}/settings/{settingId}
Code samples
cURL
# You can also use wget
curl -X DELETE /v1/users/{userId}/settings/{settingId} \
-H 'Accept: text/plain' \
-H 'x-api-key: API_KEY'
DELETE /v1/users/\{userId\}/settings/\{settingId\}
Deletes user settings based on the provided request.
Parameters
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| userId | path | string | true | The user ID. |
| settingId | path | integer(int32) | true | The setting ID. |
Example responses
200 Response
{"success":true,"code":0,"message":"string"}{
"success": true,
"code": 0,
"message": "string"
}Responses
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | OK | Management.DeleteUserSettingResponse |
Authentication: API key (x-api-key).